@@ -14,7 +14,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 
 run_help = '''TBlock - An anticapitalist ad-blocker that uses the hosts file
 Copyright (c) 2021 Twann <twann@ctemplar.com>
@@ -76,6 +76,8 @@ usage: tblockc <options> {-s|--syntax} [syntax] [file] [output_file]
   -c  --comments                          Also convert comments
   -o  --original     <syntax>             Specify the original syntax of the filter to convert
   -s  --syntax       <syntax>             Specify the new syntax to use (required)
+* Other
+  -g  --get-syntax   [file]               Scan a filter to get its syntax
 
 <syntax>
   adblockplus                             AdBlock Plus syntax
@@ -83,5 +85,6 @@ usage: tblockc <options> {-s|--syntax} [syntax] [file] [output_file]
   dnsmasq                                 dnsmasq.conf syntax
   list                                    Simple domain blacklist
   tblock                                  TBlock filter syntax
+  opera                                   Opera filter syntax
 
 For more information, see tblockc(1)'''
