@@ -32,6 +32,7 @@ from . import __version__, run_help, run_converter_help
 from .rules import add_user_rule, delete_user_rule, list_rules
 from .core import Policy, Filter, update_hosts, Rule, restore_hosts
 from .utils import check_root
+from .converter.detector import detect_syntax
 from .converter.output import convert_filter
 from .filters import update_all_filters, update_filter, update_remote_repo, subscribe_to_filter, unsubscribe_to_filter,\
     list_filters, show_filter_info, change_filter_permissions
@@ -489,62 +490,76 @@ def run_converter() -> None:
                 force = True
             else:
                 force = False
-            input_file = None
-            output_file = None
-            permissions = 'abr'
-            syntax = None
-            original_syntax = None
-            comments = False
-            try:
-                if '-r' in sys.argv:
-                    permissions = sys.argv[sys.argv.index('-r') + 1]
-                elif '--rules' in sys.argv:
-                    permissions = sys.argv[sys.argv.index('--rules') + 1]
-                elif re.match(r"^-.*r", sys.argv[1]):
-                    permissions = sys.argv[2]
-            except IndexError:
-                sys.exit('Error: you need to specify rule policies to convert')
-            try:
-                if '-o' in sys.argv:
-                    original_syntax = sys.argv[sys.argv.index('-o') + 1]
-                elif '--original' in sys.argv:
-                    original_syntax = sys.argv[sys.argv.index('--original') + 1]
-                elif re.match(r"^-.*o", sys.argv[1]):
-                    original_syntax = sys.argv[2]
-            except IndexError:
-                sys.exit('Error: you need to specify rule policies to convert')
-            try:
-                if '-s' in sys.argv:
-                    syntax = sys.argv[sys.argv.index('-s') + 1]
-                elif '--syntax' in sys.argv:
-                    syntax = sys.argv[sys.argv.index('--syntax') + 1]
-                elif re.match(r"^-.*s", sys.argv[1]):
-                    syntax = sys.argv[2]
-            except IndexError:
-                sys.exit('Error: you need to specify output syntax to use')
-            if '-c' in sys.argv or '--comments' in sys.argv or re.findall(r"^-.*c", sys.argv[1]):
-                comments = True
-            for arg in sys.argv[1:]:
-                if not re.findall(r"^-[0-9a-zA-Z\-]", arg) and not arg == input_file and not arg == output_file and \
-                        not arg == permissions and not arg == syntax and not arg == original_syntax:
-                    if input_file is None:
-                        input_file = arg
-                    elif output_file is None:
-                        output_file = arg
-                    else:
-                        sys.exit(f'Error: option {arg} is invalid')
-            if syntax is None:
-                sys.exit('Error: you need to specify output syntax with "--syntax"')
-            elif input_file is None:
-                sys.exit('Error: you need to specify the file to convert')
-            elif output_file is None:
-                sys.exit('Error: you need to specify an output file where to write converted filter')
+            if '-g' in sys.argv or '--get-syntax' in sys.argv or re.findall(r"^-g", sys.argv[1]):
+                file_to_scan = None
+                for arg in sys.argv[1:]:
+                    if not re.findall(r"^-[0-9a-zA-Z\-]", arg) and not arg == file_to_scan:
+                        file_to_scan = arg
+                        break
+                if file_to_scan is None:
+                    sys.exit('Error: you need to specify the file to scan')
+                elif not os.path.isfile(os.path.realpath(file_to_scan)):
+                    sys.exit(f'Error: file not found: "{file_to_scan}"')
+                else:
+                    with open(file_to_scan, 'rt') as f:
+                        print(f' => Syntax detected: {detect_syntax(f)}')
             else:
-                allow = True if 'a' in permissions else False
-                block = True if 'b' in permissions else False
-                redirect = True if 'r' in permissions else False
-                convert_filter(input_file, output_file, syntax, original_syntax, allow, block, redirect, comments,
-                               force=force)
+                input_file = None
+                output_file = None
+                permissions = 'abr'
+                syntax = None
+                original_syntax = None
+                comments = False
+                try:
+                    if '-r' in sys.argv:
+                        permissions = sys.argv[sys.argv.index('-r') + 1]
+                    elif '--rules' in sys.argv:
+                        permissions = sys.argv[sys.argv.index('--rules') + 1]
+                    elif re.match(r"^-.*r", sys.argv[1]):
+                        permissions = sys.argv[2]
+                except IndexError:
+                    sys.exit('Error: you need to specify rule policies to convert')
+                try:
+                    if '-o' in sys.argv:
+                        original_syntax = sys.argv[sys.argv.index('-o') + 1]
+                    elif '--original' in sys.argv:
+                        original_syntax = sys.argv[sys.argv.index('--original') + 1]
+                    elif re.match(r"^-.*o", sys.argv[1]):
+                        original_syntax = sys.argv[2]
+                except IndexError:
+                    sys.exit('Error: you need to specify rule policies to convert')
+                try:
+                    if '-s' in sys.argv:
+                        syntax = sys.argv[sys.argv.index('-s') + 1]
+                    elif '--syntax' in sys.argv:
+                        syntax = sys.argv[sys.argv.index('--syntax') + 1]
+                    elif re.match(r"^-.*s", sys.argv[1]):
+                        syntax = sys.argv[2]
+                except IndexError:
+                    sys.exit('Error: you need to specify output syntax to use')
+                if '-c' in sys.argv or '--comments' in sys.argv or re.findall(r"^-.*c", sys.argv[1]):
+                    comments = True
+                for arg in sys.argv[1:]:
+                    if not re.findall(r"^-[0-9a-zA-Z\-]", arg) and not arg == input_file and not arg == output_file and \
+                            not arg == permissions and not arg == syntax and not arg == original_syntax:
+                        if input_file is None:
+                            input_file = arg
+                        elif output_file is None:
+                            output_file = arg
+                        else:
+                            sys.exit(f'Error: option {arg} is invalid')
+                if syntax is None:
+                    sys.exit('Error: you need to specify output syntax with "--syntax"')
+                elif input_file is None:
+                    sys.exit('Error: you need to specify the file to convert')
+                elif output_file is None:
+                    sys.exit('Error: you need to specify an output file where to write converted filter')
+                else:
+                    allow = True if 'a' in permissions else False
+                    block = True if 'b' in permissions else False
+                    redirect = True if 'r' in permissions else False
+                    convert_filter(input_file, output_file, syntax, original_syntax, allow, block, redirect, comments,
+                                   force=force)
     except KeyboardInterrupt:
         print("\ntblockc: received interrupt signal")
         sys.exit(1)
