@@ -49,15 +49,24 @@ def setup_database(db_path: str) -> None:
         db.commit()
 
 
-database = '/var/lib/tblock/storage.sqlite'
-default_hosts = '/var/lib/tblock/hosts'
 hosts = '/etc/hosts'
-tmp_dir = '/tmp/tblock/'
 remote_repo = 'https://codeberg.org/tblock/remote-filters-repository/raw/branch/main/index.xml'
-remote_repo_mirror = 'https://0xacab.org/twann/remote-filters-repository-mirror/-/raw/main/index.xml'
+remote_repo_mirror = [
+    'https://0xacab.org/twann/remote-filters-repository-mirror/-/raw/main/index.xml',
+    'https://git.disroot.org/tblock/remote-filters-repository/raw/branch/main/index.xml',
+]
 default_ip = '127.0.0.1'
-remote_repo_version_db = '/var/lib/tblock/repo'
-lib_dir = '/var/lib/tblock/'
+
+if os.getenv('TERMUX_VERSION') is not None:
+    tmp_dir = os.path.join(os.getenv('TMPDIR'), 'tblock')
+    lib_dir = os.path.join(os.getenv('PREFIX'), 'tblock')
+else:
+    lib_dir = '/var/lib/tblock/'
+    tmp_dir = '/tmp/tblock/'
+
+database = os.path.join(lib_dir, 'storage.sqlite')
+remote_repo_version_db = os.path.join(lib_dir, 'repo')
+default_hosts = os.path.join(lib_dir, 'hosts')
 
 try:
     if not os.path.isdir(tmp_dir):
