@@ -499,11 +499,11 @@ class Rule:
             dict: Stats inside a dictionary
         """
         return {
-            "total": len(Rule.fetch_all_rules(db).keys()),
-            "allow": len(db.cursor().execute('SELECT "domain" FROM "rules" WHERE policy="allow";').fetchall()),
-            "block": len(db.cursor().execute('SELECT "domain" FROM "rules" WHERE policy="block";').fetchall()),
-            "redirect": len(db.cursor().execute('SELECT "domain" FROM "rules" WHERE policy="redirect";').fetchall()),
-            "user": len(db.cursor().execute('SELECT "domain" FROM "rules" WHERE priority=1;').fetchall())
+            "total": db.cursor().execute('SELECT COUNT() FROM rules;').fetchone()[0],
+            "allow": db.cursor().execute('SELECT COUNT() FROM rules WHERE policy="allow";').fetchone()[0],
+            "block": db.cursor().execute('SELECT COUNT() FROM rules WHERE policy="block";').fetchone()[0],
+            "redirect": db.cursor().execute('SELECT COUNT() FROM rules WHERE policy="redirect";').fetchone()[0],
+            "user": db.cursor().execute('SELECT COUNT() FROM rules WHERE priority=1;').fetchone()[0],
         }
 
 
