@@ -92,7 +92,7 @@ def subscribe_to_filter(filter_id: str, db_path: str, tmp_dir: str, permissions:
                 if verbosity:
                     print(' => Added new custom filter into database')
             db.close()
-            update_filter(filter_id, db_path, tmp_dir, verbosity, force)
+            update_filter(filter_id, db_path, tmp_dir, verbosity, force=True)
         else:
             db.close()
 
@@ -212,6 +212,7 @@ def update_filter(filter_id: str, db_path: str, tmp_dir: str, verbosity: bool =
         Filter(filter_id, db).remove_all_rules()
         if verbosity:
             print(' => Removing all previous rules from filter: done')
+        # Only remove local filter if filter has been downloaded, not if it is a local file
         if new_filter.source != tmp_filter:
             os.remove(tmp_filter)
         count = 1
@@ -228,6 +229,11 @@ def update_filter(filter_id: str, db_path: str, tmp_dir: str, verbosity: bool =
                 pass
             elif all_rules[rule][0] == Policy.allow and allow or all_rules[rule][0] == Policy.block and block:
                 if rule in all_rules_in_db:
+                    if all_rules[rule][0] == Policy.block and all_rules_in_db[rule]['policy'] \
+                            in [Policy.redirect, Policy.allow] or all_rules[rule][0] == Policy.redirect \
+                            and all_rules_in_db[rule]['policy'] == Policy.allow:
+                        print('yo')
+                        continue
                     sql = 'UPDATE "rules" SET policy=?, filter_id=?, priority=? WHERE domain=?;'
                     params = (all_rules[rule][0], filter_id, False, rule)
                     cursor.execute(sql, params)
@@ -309,18 +315,18 @@ def change_filter_permissions(filter_id: str, db_path: str, tmp_dir: str,
         if force or prompt_user(f'You are about to change permissions of filter: "{filter_id}"'):
             new_filter.change_permissions(permissions)
             db.close()
-            update_filter(filter_id, db_path, tmp_dir, verbosity, force)
+            update_filter(filter_id, db_path, tmp_dir, verbosity, force=True)
         else:
             db.close()
 
 
-def update_remote_repo(repo_url: str, repo_mirror: str, version_file: str,
+def update_remote_repo(repo_url: str, repo_mirror: list, version_file: str,
                        db_path: str, tmp_dir: str, verbosity: bool = True, force: bool = False) -> None:
     """Update remote filters repository
 
     Args:
         repo_url (str): The URL of the remote repo index
-        repo_mirror (str): The URL of the remote repo index mirror, in case main index is inaccessible
+        repo_mirror (list): The URLs of the remote repo index mirrors, in case main index is inaccessible
         version_file (str): The path to the file that contains local version info
         db_path (str): The path to the SQLite database
         tmp_dir (str): The directory where to store temporary files
@@ -348,17 +354,28 @@ def update_remote_repo(repo_url: str, repo_mirror: str, version_file: str,
             urllib3.exceptions.NewConnectionError):
         if verbosity:
             print(' => Failed to get index')
-            print(f' => Get mirror: {repo_mirror}')
-        try:
-            download_file(repo_mirror, tmp_index)
-        except (requests.exceptions.ConnectionError, urllib3.exceptions.MaxRetryError, ConnectionRefusedError,
-                urllib3.exceptions.NewConnectionError):
-            if verbosity:
-                print(' => Failed to get mirror')
-                print(' => Failed to update remote repository')
-            db.close()
-            sys.exit(1)
-    data = ElementTree.parse(tmp_index).getroot()
+        for mirror in repo_mirror:
+            try:
+                if verbosity:
+                    print(f' => Get mirror: {mirror}')
+                download_file(mirror, tmp_index)
+            except (requests.exceptions.ConnectionError, urllib3.exceptions.MaxRetryError, ConnectionRefusedError,
+                    urllib3.exceptions.NewConnectionError):
+                if verbosity:
+                    print(f' => Failed to get mirror: {mirror}')
+                if repo_mirror.index(mirror) == len(repo_mirror) - 1:
+                    if verbosity:
+                        print(' => Failed to update remote repository')
+                    db.close()
+                    sys.exit(1)
+    try:
+        data = ElementTree.parse(tmp_index).getroot()
+    except ElementTree.ParseError:
+        if verbosity:
+            print(' => Repository seems invalid')
+            print(' => Failed to update remote repository')
+        db.close()
+        sys.exit(1)
     if os.path.isfile(os.path.realpath(version_file)):
         with open(os.path.realpath(version_file), 'rt') as f:
             current_version = int(f.read())
